struct Attributes {
start_index: usize,
end_index: usize,
props: FontProperties,
}Expand description
A range onto which font properties are applied.
The indices are relative to a certain string, which is then passed on to Pango. The font properties will get translated to a pango::AttrList.
Fields
start_index: usizeStart byte offset within the text of FormattedText.
end_index: usizeEnd byte offset within the text of FormattedText.
props: FontPropertiesFont style and properties for this range of text.