fn build_pango_attr_list(
session: &Session,
formatted_text: &FormattedText,
) -> AttrListExpand description
Builds a Pango attribute list from a FormattedText structure.
This function converts the text styling information in FormattedText into Pango attributes that can be applied to a Pango layout.